"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.optimizeTocArray = void 0;
/**
 * Utility function to efficiently handle large table of contents arrays
 * by removing duplicates and optionally limiting size
 */
const optimizeTocArray = (tocEntries, reporter, options = {}) => {
    const { maxSize = 1000, // Maximum entries to include
    warnThreshold = 300, // Threshold to issue warning
    removeDuplicates = true, // Whether to remove duplicates
     } = options;
    if (!tocEntries || tocEntries.length === 0) {
        return [];
    }
    // Track memory usage for large TOCs
    if (tocEntries.length > warnThreshold) {
        reporter.warn(`Large table of contents detected (${tocEntries.length} items). This might affect performance.`);
    }
    // Remove duplicates if requested
    let processedToc = tocEntries;
    if (removeDuplicates) {
        const startTime = Date.now();
        const uniqueMap = new Map();
        // Use a map for faster duplicate removal - O(n) instead of O(n²)
        for (const entry of tocEntries) {
            uniqueMap.set(entry.hash, entry);
        }
        processedToc = Array.from(uniqueMap.values());
        const removedCount = tocEntries.length - processedToc.length;
        const processTime = Date.now() - startTime;
        if (removedCount > 0) {
            reporter.info(`Removed ${removedCount} duplicate TOC entries in ${processTime}ms.`);
        }
    }
    // Limit size if necessary
    if (processedToc.length > maxSize) {
        reporter.warn(`Table of contents exceeds maximum size (${processedToc.length} > ${maxSize}). Truncating.`);
        processedToc = processedToc.slice(0, maxSize);
    }
    return processedToc;
};
exports.optimizeTocArray = optimizeTocArray;
